==> duiba-live-activity-center-api-test1-20220627.074637-7-sources.jar: cn/com/duiba/live/activity/center/api/remoteservice/citic/mgm/RemoteMgmUserWishDetailService.java <==
package cn.com.duiba.live.activity.center.api.remoteservice.citic.mgm;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.live.activity.center.api.dto.citic.mgm.MgmUserWishDetailDto;
import cn.com.duiba.live.activity.center.api.param.mgm.WishSearchParam;
import cn.com.duiba.live.tool.response.result.PageResult;

import java.util.List;

/**
 * @author zhuenhui
 * @date 2022/05/24 10:21
 * @description 中信MGM活动 - 用户心愿单商品详情 RPC 接口
 */
@AdvancedFeignClient
public interface RemoteMgmUserWishDetailService {

    /**
     * 新增/更新用户心愿单
     *
     * @param activityId  活动Id
     * @param liveUserId  用户Id
     * @param mgmGoodsIds 邀请商品Id列表
     * @param expire 有效天数
     * @return 执行结果
     */
    int saveOrUpdate(Long activityId, Long liveUserId, List<Long> mgmGoodsIds, Integer expire);

    /**
     * 查询用户心愿单列表
     *
     * @param activityId 活动Id
     * @param liveUserId 用户Id
     * @return 心愿单列表
     */
    List<MgmUserWishDetailDto> listByActivityIdAndLiveUserId(Long activityId, Long liveUserId);

    /**
     * 查询用户心愿单商品
     *
     * @param activityId 活动Id
     * @param liveUserId 用户Id
     * @param mgmGoodsId mgm商品Id
     * @return 心愿单商品
     */
    MgmUserWishDetailDto findUserMgmGoods(Long activityId, Long liveUserId, Long mgmGoodsId);

    /**
     * 批量删除用户心愿单
     *
     * @param activityId  活动Id
     * @param liveUserId  用户Id
     * @param mgmGoodsIds 邀请商品Id列表
     * @return 执行结果
     */
    int batchDelete(Long activityId, Long liveUserId, List<Long> mgmGoodsIds);

    /**
     * 批量过期用户心愿单
     * @param activityId
     * @param liveUserId
     * @param mgmGoodsIds
     * @return
     */
    int batchUpdateExpire(Long activityId, Long liveUserId, List<Long> mgmGoodsIds);

    /**
     * 统计过期用户心愿单总数
     * @param param
     * @return
     */
    int countExpireUserMgmGoods(WishSearchParam param);

    /**
     * 分页查询过期用户心愿单
     * @param param
     * @return
     */
    List<MgmUserWishDetailDto> pageExpireUserMgmGoods(WishSearchParam param);

}

==> duiba-live-activity-center-api-test1-20220628.022746-9-sources.jar: cn/com/duiba/live/activity/center/api/remoteservice/citic/mgm/RemoteMgmUserWishDetailService.java <==
package cn.com.duiba.live.activity.center.api.remoteservice.citic.mgm;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.live.activity.center.api.dto.citic.mgm.MgmUserWishDetailDto;
import cn.com.duiba.live.activity.center.api.param.mgm.WishSearchParam;
import cn.com.duiba.live.tool.response.result.PageResult;

import java.util.List;

/**
 * @author zhuenhui
 * @date 2022/05/24 10:21
 * @description 中信MGM活动 - 用户心愿单商品详情 RPC 接口
 */
@AdvancedFeignClient
public interface RemoteMgmUserWishDetailService {

    /**
     * 新增/更新用户心愿单
     *
     * @param activityId  活动Id
     * @param liveUserId  用户Id
     * @param mgmGoodsIds 邀请商品Id列表
     * @param expire 有效天数
     * @return 执行结果
     */
    int saveOrUpdate(Long activityId, Long liveUserId, List<Long> mgmGoodsIds, Integer expire);

    /**
     * 查询用户心愿单列表
     *
     * @param activityId 活动Id
     * @param liveUserId 用户Id
     * @return 心愿单列表
     */
    List<MgmUserWishDetailDto> listByActivityIdAndLiveUserId(Long activityId, Long liveUserId);

    /**
     * 查询用户心愿单商品
     *
     * @param activityId 活动Id
     * @param liveUserId 用户Id
     * @param mgmGoodsId mgm商品Id
     * @return 心愿单商品
     */
    MgmUserWishDetailDto findUserMgmGoods(Long activityId, Long liveUserId, Long mgmGoodsId);

    /**
     * 批量删除用户心愿单
     *
     * @param activityId  活动Id
     * @param liveUserId  用户Id
     * @param mgmGoodsIds 邀请商品Id列表
     * @return 执行结果
     */
    int batchDelete(Long activityId, Long liveUserId, List<Long> mgmGoodsIds);

    /**
     * 批量过期用户心愿单
     * @param activityId
     * @param liveUserId
     * @param mgmGoodsIds
     * @return
     */
    Integer batchUpdateExpire(Long activityId, Long liveUserId, List<Long> mgmGoodsIds);

    /**
     * 统计过期用户心愿单总数
     * @param param
     * @return
     */
    Integer countExpireUserMgmGoods(WishSearchParam param);

    /**
     * 分页查询过期用户心愿单
     * @param param
     * @return
     */
    List<MgmUserWishDetailDto> pageExpireUserMgmGoods(WishSearchParam param);

}
